@@ -39,7 +39,7 @@ targetLangs = ['es', 'pt']
 
 # Diretório fonte
 
-sourceDir = 'amostra/' + '_'.join(sourceLang.split('-')).lower()
+sourceDir = '_'.join(sourceLang.split('-')).lower()
 
 # Preservação da sintaxe Markdown DocFX
 
